@@ -354,7 +354,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HGBRANCH': '',
  'HGTAG': '',
  'HGVERSION': '',
- 'HOST_GNU_TYPE': 'armv5tel-unknown-linux-gnueabi',
+ 'HOST_GNU_TYPE': 'armv7l-unknown-linux-gnueabi',
  'HURD_C_THREADS': 0,
  'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python2.7 /usr/include/python2.7',
  'INCLUDEDIR': '/usr/include',
@@ -535,9 +535,9 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
  'abs_builddir': '/build/python2/src/Python-2.7.11',
  'abs_srcdir': '/build/python2/src/Python-2.7.11',
- 'build': 'armv5tel-unknown-linux-gnueabi',
+ 'build': 'armv7l-unknown-linux-gnueabi',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
- 'host': 'armv5tel-unknown-linux-gnueabi',
+ 'host': 'armv7l-unknown-linux-gnueabi',
  'prefix': '/usr',
  'srcdir': '.'}
